function rest_low8_ffi,index,data,qdebug=qdebug,bug2=bug2,lc=lc
;+
;NAME:
;	rest_low8_ffi
;PURPOSE:
;	To restore a cube of low8 FFI data.  The input data must
;	consist of low-8 AND compressed data.  The output will
;	have the same number of images as the input (ie: some
;	images are simple decompressed images, not 12-bit images)
;RESTRICTION:
;	The input data needs to all be FFI data.
;	Program requires raw SFR data.
;	Low8 and compressed images must be taken within 20 minutes
;	   of each other.  This is determined in sxt_low8_match.pro.
;SAMPLE CALLING SEQUENCE:
;	data = rest_low8_ffi(index, data)
;INPUT:
;	index	- The index structure
;	data	- The data cube, may be mixed resolutions and 
;		  can contain any sort of images in addition
;		  to the NaBan and WdBan images.
;OUTPUT
;	Returns the datacube 12-bit restored images for qualifying
;	low8 images.  Returned datacube has been decompressed but
;	not otherwise processed.  sxt_prep is only used for alignment
;	of the compressed to the low8 images.
;HISTORY:
;	 2-Nov-2004 LWA  Written, borrowing from rest_low8_cube.
;-

siz=size(data)
cx=siz(1)
cy=siz(2)
out=sxt_decomp(data)

lc=sxt_low8_match(index)
oklc=where(lc(1,*) ne -1,nne)
if (nne ne 0) then begin
   for i=0,nne-1 do begin	
      both_img = [[[out(*,*,lc(0,oklc(i)))]],[[out(*,*,lc(1,oklc(i)))]]]
      res=gt_res(index(lc(0,oklc(i))))
      ;Align C image to L image, no roll correction (usually tiny).
      sxt_prep,index([lc(0,oklc(i)),lc(1,oklc(i))]),both_img,outres=res,$
         ref_image=index(lc(0,oklc(i))),/reg,iout,dout,/quiet
      dsiz=size(dout)
      comp=intarr(cx,cy)
      comp(0:dsiz(1)-1,0:dsiz(2)-1)=dout(*,*,1)
      ;Now do the restoration.
      out(0,0,oklc(i)) = restore_low8(data(*,*,lc(0,oklc(i))),comp)
      if (keyword_set(bug2)) then begin
         wdef,12,cx*2,cy,/already,/ur
         tvscl,dout(*,*,0)	;low-8 data
         ocontour,dout(*,*,1)
         tvscl,out(*,*,oklc(i)),cx,0
	 stop
      endif
   endfor
endif
if keyword_set(qdebug) then stop
return, out
end
